@@ -1,7 +1,4 @@
-pub mod inst_dump_buf;
-#[cfg(target_arch = "x86")]
-pub mod x86_64;
-#[cfg(target_arch = "x86_64")]
+pub mod riscv;
 pub mod x86_64;
 
 #[derive(Debug, Clone, Copy)]
@@ -25,3 +22,7 @@ impl ImmByte {
         }
     }
 }
+
+
+#[derive(Debug, Clone)]
+pub struct LinkError(pub String);
\ No newline at end of file
